@@ -1,5 +1,5 @@
 /* jpnevulator - serial reader/writer
- * Copyright (C) 2006-2012 Freddy Spierenburg
+ * Copyright (C) 2006-2014 Freddy Spierenburg
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,9 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-unsigned short checksumCalculate(unsigned char *data,unsigned short length) {
-	unsigned short checksum,index;
+unsigned short checksumCalculate(unsigned char *data,int length) {
+	unsigned short checksum;
+	int index;
 	for(index=0,checksum=0;index<length;index++) {
 		checksum+=data[index];
 	}
