@@ -1,5 +1,5 @@
 /* jpnevulator - serial reader/writer
- * Copyright (C) 2006-2012 Freddy Spierenburg
+ * Copyright (C) 2006-2014 Freddy Spierenburg
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,9 +43,9 @@ static unsigned short crcAdd(unsigned short crc,unsigned char byte) {
 	return(crc>>8)^crcTable[(crc&0xFF)^byte];
 }
 
-unsigned short crc16Calculate(unsigned char *data,unsigned short length) {
+unsigned short crc16Calculate(unsigned char *data,int length) {
 	unsigned short crc;
-	unsigned short index;
+	int index;
 	crc=0;
 	for(index=0;index<length;index++) {
 		crc=crcAdd(crc,data[index]);
