@@ -1,5 +1,5 @@
 /* jpnevulator - serial reader/writer
- * Copyright (C) 2006-2012 Freddy Spierenburg
+ * Copyright (C) 2006-2014 Freddy Spierenburg
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,6 @@
 #define __CRC16_H
 
 extern void crc16TableCreate(unsigned short,unsigned short);
-extern unsigned short crc16Calculate(unsigned char *,unsigned short);
+extern unsigned short crc16Calculate(unsigned char *,int);
 
 #endif
